# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/area_of_interest_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2
from global_vo_grpc_service.protos import mission_api_pb2 as global__vo__grpc__service_dot_protos_dot_mission__api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8global_vo_grpc_service/protos/area_of_interest_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)global_vo_grpc_service/protos/utils.proto\x1a/global_vo_grpc_service/protos/mission_api.proto\"\xa9\x01\n\x0e\x41reaOfInterest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nmission_id\x18\x02 \x01(\x05\x12\x17\n\x0fgeo_polygon_wkt\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"N\n!FindOrCreateAreaOfInterestRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"q\n\"FindOrCreateAreaOfInterestResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"J\n\x1d\x46indAreaOfInterestByIdRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"m\n\x1e\x46indAreaOfInterestByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"G\n\x1aListAreaOfInterestsRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"k\n\x1bListAreaOfInterestsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12*\n\x11\x61rea_of_interests\x18\x02 \x03(\x0b\x32\x0f.AreaOfInterest\"L\n\x1fUpdateAreaOfInterestByIdRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"o\n UpdateAreaOfInterestByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"L\n\x1f\x44\x65leteAreaOfInterestByIdRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"o\n DeleteAreaOfInterestByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"u\n&GetAreaOfInterestOverlapPercentRequest\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"\x92\x01\n\'GetAreaOfInterestOverlapPercentResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\x12\x1a\n\x12overlap_percentage\x18\x03 \x01(\x02\"<\n\x1fGetAoiKmlDataByMissionIdRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\":\n GetAoiKmlDataByMissionIdResponse\x12\x16\n\x0ekml_data_bytes\x18\x01 \x01(\x0c\x32\xc2\x05\n\x11\x41reaOfInterestApi\x12\x65\n\x1a\x46indOrCreateAreaOfInterest\x12\".FindOrCreateAreaOfInterestRequest\x1a#.FindOrCreateAreaOfInterestResponse\x12Y\n\x16\x46indAreaOfInterestById\x12\x1e.FindAreaOfInterestByIdRequest\x1a\x1f.FindAreaOfInterestByIdResponse\x12P\n\x13ListAreaOfInterests\x12\x1b.ListAreaOfInterestsRequest\x1a\x1c.ListAreaOfInterestsResponse\x12_\n\x18UpdateAreaOfInterestById\x12 .UpdateAreaOfInterestByIdRequest\x1a!.UpdateAreaOfInterestByIdResponse\x12_\n\x18\x44\x65leteAreaOfInterestById\x12 .DeleteAreaOfInterestByIdRequest\x1a!.DeleteAreaOfInterestByIdResponse\x12t\n\x1fGetAreaOfInterestOverlapPercent\x12\'.GetAreaOfInterestOverlapPercentRequest\x1a(.GetAreaOfInterestOverlapPercentResponse\x12\x61\n\x18GetAoiKmlDataByMissionId\x12 .GetAoiKmlDataByMissionIdRequest\x1a!.GetAoiKmlDataByMissionIdResponse0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.area_of_interest_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AREAOFINTEREST._serialized_start=186
  _AREAOFINTEREST._serialized_end=355
  _FINDORCREATEAREAOFINTERESTREQUEST._serialized_start=357
  _FINDORCREATEAREAOFINTERESTREQUEST._serialized_end=435
  _FINDORCREATEAREAOFINTERESTRESPONSE._serialized_start=437
  _FINDORCREATEAREAOFINTERESTRESPONSE._serialized_end=550
  _FINDAREAOFINTERESTBYIDREQUEST._serialized_start=552
  _FINDAREAOFINTERESTBYIDREQUEST._serialized_end=626
  _FINDAREAOFINTERESTBYIDRESPONSE._serialized_start=628
  _FINDAREAOFINTERESTBYIDRESPONSE._serialized_end=737
  _LISTAREAOFINTERESTSREQUEST._serialized_start=739
  _LISTAREAOFINTERESTSREQUEST._serialized_end=810
  _LISTAREAOFINTERESTSRESPONSE._serialized_start=812
  _LISTAREAOFINTERESTSRESPONSE._serialized_end=919
  _UPDATEAREAOFINTERESTBYIDREQUEST._serialized_start=921
  _UPDATEAREAOFINTERESTBYIDREQUEST._serialized_end=997
  _UPDATEAREAOFINTERESTBYIDRESPONSE._serialized_start=999
  _UPDATEAREAOFINTERESTBYIDRESPONSE._serialized_end=1110
  _DELETEAREAOFINTERESTBYIDREQUEST._serialized_start=1112
  _DELETEAREAOFINTERESTBYIDREQUEST._serialized_end=1188
  _DELETEAREAOFINTERESTBYIDRESPONSE._serialized_start=1190
  _DELETEAREAOFINTERESTBYIDRESPONSE._serialized_end=1301
  _GETAREAOFINTERESTOVERLAPPERCENTREQUEST._serialized_start=1303
  _GETAREAOFINTERESTOVERLAPPERCENTREQUEST._serialized_end=1420
  _GETAREAOFINTERESTOVERLAPPERCENTRESPONSE._serialized_start=1423
  _GETAREAOFINTERESTOVERLAPPERCENTRESPONSE._serialized_end=1569
  _GETAOIKMLDATABYMISSIONIDREQUEST._serialized_start=1571
  _GETAOIKMLDATABYMISSIONIDREQUEST._serialized_end=1631
  _GETAOIKMLDATABYMISSIONIDRESPONSE._serialized_start=1633
  _GETAOIKMLDATABYMISSIONIDRESPONSE._serialized_end=1691
  _AREAOFINTERESTAPI._serialized_start=1694
  _AREAOFINTERESTAPI._serialized_end=2400
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/metric_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.global_vo_grpc_service/protos/metric_api.proto\x1a)global_vo_grpc_service/protos/utils.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x1c\n\x0bMetricValue\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\"k\n\x11MetricValueStruct\x12*\n\tdata_dict\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\tdata_list\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\"7\n!FindMissionDetectionsCountRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"c\n\"FindMissionDetectionsCountResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.MetricValue\"b\n(FindMissionDetectionCountsByStateRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\x12\"\n\x1a\x65xclude_single_pole_pylons\x18\x02 \x01(\x08\"p\n)FindMissionDetectionCountsByStateResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.MetricValueStruct\"6\n GetTotalImagesByMissionIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"b\n!GetTotalImagesByMissionIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.MetricValue2\xd2\x02\n\tMetricApi\x12\x65\n\x1a\x46indMissionDetectionCounts\x12\".FindMissionDetectionsCountRequest\x1a#.FindMissionDetectionsCountResponse\x12z\n!FindMissionDetectionCountsByState\x12).FindMissionDetectionCountsByStateRequest\x1a*.FindMissionDetectionCountsByStateResponse\x12\x62\n\x19GetTotalImagesByMissionId\x12!.GetTotalImagesByMissionIdRequest\x1a\".GetTotalImagesByMissionIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.metric_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _METRICVALUE._serialized_start=123
  _METRICVALUE._serialized_end=151
  _METRICVALUESTRUCT._serialized_start=153
  _METRICVALUESTRUCT._serialized_end=260
  _FINDMISSIONDETECTIONSCOUNTREQUEST._serialized_start=262
  _FINDMISSIONDETECTIONSCOUNTREQUEST._serialized_end=317
  _FINDMISSIONDETECTIONSCOUNTRESPONSE._serialized_start=319
  _FINDMISSIONDETECTIONSCOUNTRESPONSE._serialized_end=418
  _FINDMISSIONDETECTIONCOUNTSBYSTATEREQUEST._serialized_start=420
  _FINDMISSIONDETECTIONCOUNTSBYSTATEREQUEST._serialized_end=518
  _FINDMISSIONDETECTIONCOUNTSBYSTATERESPONSE._serialized_start=520
  _FINDMISSIONDETECTIONCOUNTSBYSTATERESPONSE._serialized_end=632
  _GETTOTALIMAGESBYMISSIONIDREQUEST._serialized_start=634
  _GETTOTALIMAGESBYMISSIONIDREQUEST._serialized_end=688
  _GETTOTALIMAGESBYMISSIONIDRESPONSE._serialized_start=690
  _GETTOTALIMAGESBYMISSIONIDRESPONSE._serialized_end=788
  _METRICAPI._serialized_start=791
  _METRICAPI._serialized_end=1129
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/role_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,global_vo_grpc_service/protos/role_api.proto\x1a)global_vo_grpc_service/protos/utils.proto\"1\n\x04Role\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07team_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\".\n\x17\x46indOrCreateRoleRequest\x12\x13\n\x04role\x18\x01 \x01(\x0b\x32\x05.Role\"Q\n\x18\x46indOrCreateRoleResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04role\x18\x02 \x01(\x0b\x32\x05.Role\"\'\n\x10ListRolesRequest\x12\x13\n\x04role\x18\x01 \x01(\x0b\x32\x05.Role\"K\n\x11ListRolesResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x14\n\x05roles\x18\x02 \x03(\x0b\x32\x05.Role2\x86\x01\n\x07RoleApi\x12G\n\x10\x46indOrCreateRole\x12\x18.FindOrCreateRoleRequest\x1a\x19.FindOrCreateRoleResponse\x12\x32\n\tListRoles\x12\x11.ListRolesRequest\x1a\x12.ListRolesResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.role_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROLE._serialized_start=91
  _ROLE._serialized_end=140
  _FINDORCREATEROLEREQUEST._serialized_start=142
  _FINDORCREATEROLEREQUEST._serialized_end=188
  _FINDORCREATEROLERESPONSE._serialized_start=190
  _FINDORCREATEROLERESPONSE._serialized_end=271
  _LISTROLESREQUEST._serialized_start=273
  _LISTROLESREQUEST._serialized_end=312
  _LISTROLESRESPONSE._serialized_start=314
  _LISTROLESRESPONSE._serialized_end=389
  _ROLEAPI._serialized_start=392
  _ROLEAPI._serialized_end=526
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/utils.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)global_vo_grpc_service/protos/utils.proto\"M\n\x07GeoBbox\x12\x0f\n\x07min_lat\x18\x01 \x01(\x02\x12\x0f\n\x07max_lat\x18\x02 \x01(\x02\x12\x0f\n\x07min_lon\x18\x03 \x01(\x02\x12\x0f\n\x07max_lon\x18\x04 \x01(\x02\"$\n\x08GeoPoint\x12\x0b\n\x03lat\x18\x01 \x01(\x02\x12\x0b\n\x03lon\x18\x02 \x01(\x02*q\n\nChangeType\x12\x17\n\x13UNKNOWN_CHANGE_TYPE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x08\n\x04READ\x10\x02\x12\x0b\n\x07UPDATED\x10\x03\x12\x0b\n\x07\x44\x45LETED\x10\x04\x12\n\n\x06\x45XISTS\x10\x05\x12\r\n\tNOT_FOUND\x10\x06\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.utils_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHANGETYPE._serialized_start=162
  _CHANGETYPE._serialized_end=275
  _GEOBBOX._serialized_start=45
  _GEOBBOX._serialized_end=122
  _GEOPOINT._serialized_start=124
  _GEOPOINT._serialized_end=160
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/query_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-global_vo_grpc_service/protos/query_api.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a)global_vo_grpc_service/protos/utils.proto\"@\n\"DetectionsWithinBoundingBoxRequest\x12\x1a\n\x08geo_bbox\x18\x01 \x01(\x0b\x32\x08.GeoBbox\"\x7f\n\rQueryResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x1c\n\tgeo_point\x18\x03 \x01(\x0b\x32\t.GeoPoint\x12\x13\n\x0b\x63\x61tegory_id\x18\x04 \x01(\x05\x12\r\n\x05score\x18\x05 \x01(\x02\"V\n\x0eQueryResponses\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\"\n\ndetections\x18\x02 \x03(\x0b\x32\x0e.QueryResponse\"*\n\x1b\x44\x65tectionsAggregatedRequest\x12\x0b\n\x03wkt\x18\x01 \x01(\t\"\xbd\x03\n\x1c\x44\x65tectionsAggregatedResponse\x12\x14\n\x0c\x64\x65tection_id\x18\x01 \x01(\x05\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x02 \x01(\x05\x12\x0b\n\x03lat\x18\x03 \x01(\x02\x12\x0b\n\x03lon\x18\x04 \x01(\x02\x12\x15\n\rcategory_name\x18\x05 \x01(\t\x12\x15\n\rcategory_enum\x18\x06 \x01(\t\x12\x11\n\tmax_score\x18\x07 \x01(\x02\x12\x18\n\x10\x65stimated_height\x18\x08 \x01(\x02\x12\x15\n\rtotal_sources\x18\t \x01(\x05\x12.\n\nfirst_seen\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tlast_seen\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bvendor_name\x18\r \x01(\t\x12\x11\n\tvendor_id\x18\x0e \x01(\t\x12(\n\x07\x66\x65\x61ture\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ndebug_data\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x8d\x01\n&GetDetectionInstancesForSearchResponse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08image_id\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x02\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0b\n\x03lat\x18\x06 \x01(\x02\x12\x0b\n\x03lon\x18\x07 \x01(\x02\x32\xa1\x02\n\x08QueryApi\x12V\n\x1eGetDetectionsWithinBoundingBox\x12#.DetectionsWithinBoundingBoxRequest\x1a\x0f.QueryResponses\x12X\n\x17GetDetectionsAggregated\x12\x1c.DetectionsAggregatedRequest\x1a\x1d.DetectionsAggregatedResponse0\x01\x12\x63\n\x1eGetDetectionInstancesForSearch\x12\x16.google.protobuf.Empty\x1a\'.GetDetectionInstancesForSearchResponse0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.query_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DETECTIONSWITHINBOUNDINGBOXREQUEST._serialized_start=184
  _DETECTIONSWITHINBOUNDINGBOXREQUEST._serialized_end=248
  _QUERYRESPONSE._serialized_start=250
  _QUERYRESPONSE._serialized_end=377
  _QUERYRESPONSES._serialized_start=379
  _QUERYRESPONSES._serialized_end=465
  _DETECTIONSAGGREGATEDREQUEST._serialized_start=467
  _DETECTIONSAGGREGATEDREQUEST._serialized_end=509
  _DETECTIONSAGGREGATEDRESPONSE._serialized_start=512
  _DETECTIONSAGGREGATEDRESPONSE._serialized_end=957
  _GETDETECTIONINSTANCESFORSEARCHRESPONSE._serialized_start=960
  _GETDETECTIONINSTANCESFORSEARCHRESPONSE._serialized_end=1101
  _QUERYAPI._serialized_start=1104
  _QUERYAPI._serialized_end=1393
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_grpc_service/protos/image_data_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-data_grpc_service/protos/image_data_api.proto\"+\n\x17GetImageDataByIdRequest\x12\x10\n\x08image_id\x18\x01 \x01(\x05\"4\n\x18GetImageDataByIdResponse\x12\x18\n\x10image_data_bytes\x18\x01 \x01(\x0c\x32Y\n\x0cImageDataApi\x12I\n\x10GetImageDataById\x12\x18.GetImageDataByIdRequest\x1a\x19.GetImageDataByIdResponse0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_grpc_service.protos.image_data_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETIMAGEDATABYIDREQUEST._serialized_start=49
  _GETIMAGEDATABYIDREQUEST._serialized_end=92
  _GETIMAGEDATABYIDRESPONSE._serialized_start=94
  _GETIMAGEDATABYIDRESPONSE._serialized_end=146
  _IMAGEDATAAPI._serialized_start=148
  _IMAGEDATAAPI._serialized_end=237
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: geospatial_toolkit_grpc_service/protos/function_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9geospatial_toolkit_grpc_service/protos/function_api.proto\"E\n\x14\x43\x61lculateAMSLRequest\x12\x0b\n\x03lat\x18\x01 \x01(\x02\x12\x0b\n\x03lon\x18\x02 \x01(\x02\x12\x13\n\x0bheight_feet\x18\x03 \x01(\x02\"B\n\x15\x43\x61lculateAMSLResponse\x12\x11\n\tamsl_feet\x18\x01 \x01(\x02\x12\x16\n\x0e\x65levation_feet\x18\x02 \x01(\x02\x32M\n\x0b\x46unctionApi\x12>\n\rCalculateAMSL\x12\x15.CalculateAMSLRequest\x1a\x16.CalculateAMSLResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'geospatial_toolkit_grpc_service.protos.function_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CALCULATEAMSLREQUEST._serialized_start=61
  _CALCULATEAMSLREQUEST._serialized_end=130
  _CALCULATEAMSLRESPONSE._serialized_start=132
  _CALCULATEAMSLRESPONSE._serialized_end=198
  _FUNCTIONAPI._serialized_start=200
  _FUNCTIONAPI._serialized_end=277
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/mission_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/global_vo_grpc_service/protos/mission_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)global_vo_grpc_service/protos/utils.proto\"\x98\x01\n\x07Mission\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x14\x43reateMissionRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x15\x43reateMissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"0\n\x13ListMissionsRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x14ListMissionsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1a\n\x08missions\x18\x02 \x03(\x0b\x32\x08.Mission\"3\n\x16\x46indMissionByIdRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"V\n\x17\x46indMissionByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"=\n LockMissionAreaOfInterestRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"`\n!LockMissionAreaOfInterestResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"1\n\x14\x44\x65leteMissionRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x15\x44\x65leteMissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"5\n\x18UpdateMissionByIdRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"X\n\x19UpdateMissionByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission2\xbf\x03\n\nMissionApi\x12>\n\rCreateMission\x12\x15.CreateMissionRequest\x1a\x16.CreateMissionResponse\x12;\n\x0cListMissions\x12\x14.ListMissionsRequest\x1a\x15.ListMissionsResponse\x12\x44\n\x0f\x46indMissionById\x12\x17.FindMissionByIdRequest\x1a\x18.FindMissionByIdResponse\x12\x62\n\x19LockMissionAreaOfInterest\x12!.LockMissionAreaOfInterestRequest\x1a\".LockMissionAreaOfInterestResponse\x12>\n\rDeleteMission\x12\x15.DeleteMissionRequest\x1a\x16.DeleteMissionResponse\x12J\n\x11UpdateMissionById\x12\x19.UpdateMissionByIdRequest\x1a\x1a.UpdateMissionByIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.mission_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MISSION._serialized_start=128
  _MISSION._serialized_end=280
  _CREATEMISSIONREQUEST._serialized_start=282
  _CREATEMISSIONREQUEST._serialized_end=331
  _CREATEMISSIONRESPONSE._serialized_start=333
  _CREATEMISSIONRESPONSE._serialized_end=417
  _LISTMISSIONSREQUEST._serialized_start=419
  _LISTMISSIONSREQUEST._serialized_end=467
  _LISTMISSIONSRESPONSE._serialized_start=469
  _LISTMISSIONSRESPONSE._serialized_end=553
  _FINDMISSIONBYIDREQUEST._serialized_start=555
  _FINDMISSIONBYIDREQUEST._serialized_end=606
  _FINDMISSIONBYIDRESPONSE._serialized_start=608
  _FINDMISSIONBYIDRESPONSE._serialized_end=694
  _LOCKMISSIONAREAOFINTERESTREQUEST._serialized_start=696
  _LOCKMISSIONAREAOFINTERESTREQUEST._serialized_end=757
  _LOCKMISSIONAREAOFINTERESTRESPONSE._serialized_start=759
  _LOCKMISSIONAREAOFINTERESTRESPONSE._serialized_end=855
  _DELETEMISSIONREQUEST._serialized_start=857
  _DELETEMISSIONREQUEST._serialized_end=906
  _DELETEMISSIONRESPONSE._serialized_start=908
  _DELETEMISSIONRESPONSE._serialized_end=992
  _UPDATEMISSIONBYIDREQUEST._serialized_start=994
  _UPDATEMISSIONBYIDREQUEST._serialized_end=1047
  _UPDATEMISSIONBYIDRESPONSE._serialized_start=1049
  _UPDATEMISSIONBYIDRESPONSE._serialized_end=1137
  _MISSIONAPI._serialized_start=1140
  _MISSIONAPI._serialized_end=1587
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/detection_instance_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import detection_api_pb2 as global__vo__grpc__service_dot_protos_dot_detection__api__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:global_vo_grpc_service/protos/detection_instance_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31global_vo_grpc_service/protos/detection_api.proto\x1a)global_vo_grpc_service/protos/utils.proto\"\xf4\x03\n\x11\x44\x65tectionInstance\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\x12\x0f\n\x07part_id\x18\x03 \x01(\x05\x12\x10\n\x08image_id\x18\x04 \x01(\x05\x12\x14\n\x0c\x64\x65tection_id\x18\x05 \x01(\x05\x12\x11\n\tsource_id\x18\x06 \x01(\x05\x12\x1a\n\x08geo_bbox\x18\x07 \x01(\x0b\x32\x08.GeoBbox\x12\r\n\x05score\x18\x08 \x01(\x02\x12\x0e\n\x06height\x18\t \x01(\x02\x12/\n\x0b\x64\x65tected_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x63\x61tegory_id\x18\x0e \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x0f \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x10 \x01(\x0b\x32\t.GeoPoint\x12\r\n\x05state\x18\x11 \x01(\t\"}\n,FindOrCreateDetectionInstanceViaHumanRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x1d\n\tdetection\x18\x02 \x01(\x0b\x32\n.Detection\"\x81\x01\n-FindOrCreateDetectionInstanceViaHumanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"\x7f\n.FindOrCreateDetectionInstanceViaMachineRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x1d\n\tdetection\x18\x02 \x01(\x0b\x32\n.Detection\"\x83\x01\n/FindOrCreateDetectionInstanceViaMachineResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"W\n%GetDetectionInstancesByImageIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"{\n&GetDetectionInstancesByImageIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12/\n\x13\x64\x65tection_instances\x18\x02 \x03(\x0b\x32\x12.DetectionInstance\"_\n-UpdateDetectionInstanceGeoBboxViaHumanRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"\x82\x01\n.UpdateDetectionInstanceGeoBboxViaHumanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"a\n/UpdateDetectionInstanceGeoBboxViaMachineRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"\x84\x01\n0UpdateDetectionInstanceGeoBboxViaMachineResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"T\n\"DeleteDetectionInstanceByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"w\n#DeleteDetectionInstanceByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"j\n\'TransitionDetectionInstanceStateRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x0f\n\x07trigger\x18\x02 \x01(\t\"\x8b\x01\n(TransitionDetectionInstanceStateResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\r\n\x05state\x18\x02 \x01(\t\x12.\n\x12\x64\x65tection_instance\x18\x03 \x01(\x0b\x32\x12.DetectionInstance\"U\n#GetDetectionInstanceBboxByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"w\n$GetDetectionInstanceBboxByIdResponse\x12\r\n\x05min_x\x18\x01 \x01(\x05\x12\r\n\x05max_x\x18\x02 \x01(\x05\x12\r\n\x05min_y\x18\x03 \x01(\x05\x12\r\n\x05max_y\x18\x04 \x01(\x05\x12\x13\n\x0b\x63\x61tegory_id\x18\x05 \x01(\x05\"V\n$GetDetectionInstanceStateByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"y\n%GetDetectionInstanceStateByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"Q\n\x1fGetDetectionInstanceByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"t\n GetDetectionInstanceByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"\xa4\x01\n/UpdateDetectionInstanceGeoPointsViaHumanRequest\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x01 \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x02 \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x03 \x01(\x0b\x32\t.GeoPoint\"\x84\x01\n0UpdateDetectionInstanceGeoPointsViaHumanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"\xa6\x01\n1UpdateDetectionInstanceGeoPointsViaMachineRequest\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x01 \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x02 \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x03 \x01(\x0b\x32\t.GeoPoint\"\x86\x01\n2UpdateDetectionInstanceGeoPointsViaMachineResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance2\x8a\x0c\n\x14\x44\x65tectionInstanceApi\x12h\n\x1b\x44\x65leteDetectionInstanceById\x12#.DeleteDetectionInstanceByIdRequest\x1a$.DeleteDetectionInstanceByIdResponse\x12\x86\x01\n%FindOrCreateDetectionInstanceViaHuman\x12-.FindOrCreateDetectionInstanceViaHumanRequest\x1a..FindOrCreateDetectionInstanceViaHumanResponse\x12\x8c\x01\n\'FindOrCreateDetectionInstanceViaMachine\x12/.FindOrCreateDetectionInstanceViaMachineRequest\x1a\x30.FindOrCreateDetectionInstanceViaMachineResponse\x12k\n\x1cGetDetectionInstanceBboxById\x12$.GetDetectionInstanceBboxByIdRequest\x1a%.GetDetectionInstanceBboxByIdResponse\x12n\n\x1dGetDetectionInstanceStateById\x12%.GetDetectionInstanceStateByIdRequest\x1a&.GetDetectionInstanceStateByIdResponse\x12_\n\x18GetDetectionInstanceById\x12 .GetDetectionInstanceByIdRequest\x1a!.GetDetectionInstanceByIdResponse\x12q\n\x1eGetDetectionInstancesByImageId\x12&.GetDetectionInstancesByImageIdRequest\x1a\'.GetDetectionInstancesByImageIdResponse\x12w\n TransitionDetectionInstanceState\x12(.TransitionDetectionInstanceStateRequest\x1a).TransitionDetectionInstanceStateResponse\x12\x89\x01\n&UpdateDetectionInstanceGeoBboxViaHuman\x12..UpdateDetectionInstanceGeoBboxViaHumanRequest\x1a/.UpdateDetectionInstanceGeoBboxViaHumanResponse\x12\x8f\x01\n(UpdateDetectionInstanceGeoBboxViaMachine\x12\x30.UpdateDetectionInstanceGeoBboxViaMachineRequest\x1a\x31.UpdateDetectionInstanceGeoBboxViaMachineResponse\x12\x8f\x01\n(UpdateDetectionInstanceGeoPointsViaHuman\x12\x30.UpdateDetectionInstanceGeoPointsViaHumanRequest\x1a\x31.UpdateDetectionInstanceGeoPointsViaHumanResponse\x12\x95\x01\n*UpdateDetectionInstanceGeoPointsViaMachine\x12\x32.UpdateDetectionInstanceGeoPointsViaMachineRequest\x1a\x33.UpdateDetectionInstanceGeoPointsViaMachineResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.detection_instance_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DETECTIONINSTANCE._serialized_start=190
  _DETECTIONINSTANCE._serialized_end=690
  _FINDORCREATEDETECTIONINSTANCEVIAHUMANREQUEST._serialized_start=692
  _FINDORCREATEDETECTIONINSTANCEVIAHUMANREQUEST._serialized_end=817
  _FINDORCREATEDETECTIONINSTANCEVIAHUMANRESPONSE._serialized_start=820
  _FINDORCREATEDETECTIONINSTANCEVIAHUMANRESPONSE._serialized_end=949
  _FINDORCREATEDETECTIONINSTANCEVIAMACHINEREQUEST._serialized_start=951
  _FINDORCREATEDETECTIONINSTANCEVIAMACHINEREQUEST._serialized_end=1078
  _FINDORCREATEDETECTIONINSTANCEVIAMACHINERESPONSE._serialized_start=1081
  _FINDORCREATEDETECTIONINSTANCEVIAMACHINERESPONSE._serialized_end=1212
  _GETDETECTIONINSTANCESBYIMAGEIDREQUEST._serialized_start=1214
  _GETDETECTIONINSTANCESBYIMAGEIDREQUEST._serialized_end=1301
  _GETDETECTIONINSTANCESBYIMAGEIDRESPONSE._serialized_start=1303
  _GETDETECTIONINSTANCESBYIMAGEIDRESPONSE._serialized_end=1426
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANREQUEST._serialized_start=1428
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANREQUEST._serialized_end=1523
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANRESPONSE._serialized_start=1526
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANRESPONSE._serialized_end=1656
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINEREQUEST._serialized_start=1658
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINEREQUEST._serialized_end=1755
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINERESPONSE._serialized_start=1758
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINERESPONSE._serialized_end=1890
  _DELETEDETECTIONINSTANCEBYIDREQUEST._serialized_start=1892
  _DELETEDETECTIONINSTANCEBYIDREQUEST._serialized_end=1976
  _DELETEDETECTIONINSTANCEBYIDRESPONSE._serialized_start=1978
  _DELETEDETECTIONINSTANCEBYIDRESPONSE._serialized_end=2097
  _TRANSITIONDETECTIONINSTANCESTATEREQUEST._serialized_start=2099
  _TRANSITIONDETECTIONINSTANCESTATEREQUEST._serialized_end=2205
  _TRANSITIONDETECTIONINSTANCESTATERESPONSE._serialized_start=2208
  _TRANSITIONDETECTIONINSTANCESTATERESPONSE._serialized_end=2347
  _GETDETECTIONINSTANCEBBOXBYIDREQUEST._serialized_start=2349
  _GETDETECTIONINSTANCEBBOXBYIDREQUEST._serialized_end=2434
  _GETDETECTIONINSTANCEBBOXBYIDRESPONSE._serialized_start=2436
  _GETDETECTIONINSTANCEBBOXBYIDRESPONSE._serialized_end=2555
  _GETDETECTIONINSTANCESTATEBYIDREQUEST._serialized_start=2557
  _GETDETECTIONINSTANCESTATEBYIDREQUEST._serialized_end=2643
  _GETDETECTIONINSTANCESTATEBYIDRESPONSE._serialized_start=2645
  _GETDETECTIONINSTANCESTATEBYIDRESPONSE._serialized_end=2766
  _GETDETECTIONINSTANCEBYIDREQUEST._serialized_start=2768
  _GETDETECTIONINSTANCEBYIDREQUEST._serialized_end=2849
  _GETDETECTIONINSTANCEBYIDRESPONSE._serialized_start=2851
  _GETDETECTIONINSTANCEBYIDRESPONSE._serialized_end=2967
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANREQUEST._serialized_start=2970
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANREQUEST._serialized_end=3134
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANRESPONSE._serialized_start=3137
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANRESPONSE._serialized_end=3269
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINEREQUEST._serialized_start=3272
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINEREQUEST._serialized_end=3438
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINERESPONSE._serialized_start=3441
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINERESPONSE._serialized_end=3575
  _DETECTIONINSTANCEAPI._serialized_start=3578
  _DETECTIONINSTANCEAPI._serialized_end=5124
# @@protoc_insertion_point(module_scope)
